# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-28 13:54
from __future__ import unicode_literals

from django.db import migrations
from django.db.migrations import RunPython
from django.db.models import Count, Q


def forward(apps, schema_editor):
    Content = apps.get_model("content", "Content")
    qs = Content.objects.annotate(child_count=Count("children"), share_count=Count("shares")).filter(
        Q(child_count__gt=0) | Q(share_count__gt=0) | Q(author__user__isnull=False))
    for content in qs:
        # Replies
        share_ids = Content.objects.filter(share_of=content).values_list("id", flat=True)
        reply_count = content.children.count() + Content.objects.filter(parent_id__in=share_ids).count()
        # Shares
        shares_count = content.shares.count()
        # Local
        local = True if content.author.user else False
        Content.objects.filter(id=content.id).update(
            reply_count=reply_count, shares_count=shares_count, local=local,
        )


class Migration(migrations.Migration):

    dependencies = [
        ('content', '0021_add_local_and_reply_and_shares_counts_to_content'),
    ]

    operations = [
        RunPython(forward, RunPython.noop),
    ]
